jenkins-bot has submitted this change and it was merged.

Change subject: Switched to JobQueueFederated
......................................................................


Switched to JobQueueFederated

* rdb1 one partition is the current redis server, so the jobs carry over

Change-Id: I1da1b30e2fef0ef1152aada7095ef5ff51d9acf4
---
M wmf-config/jobqueue-eqiad.php
1 file changed, 27 insertions(+), 8 deletions(-)

Approvals:
  Aaron Schulz: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/wmf-config/jobqueue-eqiad.php b/wmf-config/jobqueue-eqiad.php
index e965c3d..37049a1 100644
--- a/wmf-config/jobqueue-eqiad.php
+++ b/wmf-config/jobqueue-eqiad.php
@@ -1,15 +1,34 @@
 <?php
 # WARNING: This file is publically viewable on the web. Do not put private 
data here.
 
 // Note: on server failure, this should be switched to the slave
 $wgJobTypeConf['default'] = array(
-       'class'       => 'JobQueueRedis',
-       'redisServer' => '10.64.32.76', # rdb1001 (master)
-       #'redisServer' => '10.64.32.77', # rdb1002 (slave)
-       'redisConfig' => array(
-               'connectTimeout' => 2,
-               'password' => $wmgRedisPassword,
-               'compression' => 'gzip'
+       'class'               => 'JobQueueFederated',
+       'configByPartition'   => array(
+               'rdb1' => array(
+                       'class'       => 'JobQueueRedis',
+                       'redisServer' => '10.64.32.76', # rdb1001 (master)
+                       #'redisServer' => '10.64.32.77', # rdb1002 (slave)
+                       'redisConfig' => array(
+                               'connectTimeout' => 2,
+                               'password' => $wmgRedisPassword,
+                               'compression' => 'gzip'
+                       )
+               ),
+               'rdb2' => array(
+                       'class'       => 'JobQueueRedis',
+                       'redisServer' => '10.64.0.201', # rdb1003 (master)
+                       #'redisServer' => '10.64.16.183', # rdb1004 (slave)
+                       'redisConfig' => array(
+                               'connectTimeout' => 2,
+                               'password' => $wmgRedisPassword,
+                               'compression' => 'gzip'
+                       )
+               ),
+       ),
+       'sectionsByWiki'      => array(), // default
+       'partitionsBySection' => array(
+               'default' => array( 'rdb1' => 50, 'rdb2' => 50 ),
        )
 );
 // Note: on server failure, this should be changed to any other redis server
@@ -1,15 +1,34 @@
data here.
 
-// Note: on server failure, this should be switched to the slave
+// Note: on server failure, partition masters should be switched to the slave
 $wgJobTypeConf['default'] = array(

-- 
To view, visit https://gerrit.wikimedia.org/r/92032
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I1da1b30e2fef0ef1152aada7095ef5ff51d9acf4
Gerrit-PatchSet: 1
Gerrit-Project: operations/mediawiki-config
Gerrit-Branch: master
Gerrit-Owner: Aaron Schulz <[email protected]>
Gerrit-Reviewer: Aaron Schulz <[email protected]>
Gerrit-Reviewer: jenkins-bot

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to